/*
mobius.c

Written by Windell Oskay, http://www.evilmadscientist.com/

This is free software; please modify it and use it to do cool stuff.

This avr-gcc program for the Atmel ATTiny2313 
runs a LED chaser with 17 LEDs
 
 Usage:
 If necessary, edit the Makefile with your AVR programmer and port. (We use usbtiny.)
 
 Move into the directory with this file and the makefile.
 Type: 
 make all <CR>
 make install <CR>
 
 You should get a response like:
 
 avrdude: verifying ...
avrdude: 334 bytes of flash verified

avrdude: safemode: lfuse reads as 62
avrdude: safemode: hfuse reads as DF
avrdude: safemode: efuse reads as FF
avrdude: safemode: Fuses OK

avrdude done.  Thank you.

 
 
*/

 

	
/* Visualize outputs:

Single chaser:

LED   D0 D1 A1 A0 D2 D3 D4 D5 D6 B0 B1 B2 B3 B4 B5 B6 B7    PA     PB     PD
0     1  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0      0      0      1
1     0  1  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0      0      0      2
2     0  0  1  0  0  0  0  0  0  0  0  0  0  0  0  0  0      2      0      0
3     0  0  0  1  0  0  0  0  0  0  0  0  0  0  0  0  0      1      0      0
4     0  0  0  0  1  0  0  0  0  0  0  0  0  0  0  0  0      0      0      4
5     0  0  0  0  0  1  0  0  0  0  0  0  0  0  0  0  0      0      0      8
6     0  0  0  0  0  0  1  0  0  0  0  0  0  0  0  0  0      0      0     16
7     0  0  0  0  0  0  0  1  0  0  0  0  0  0  0  0  0      0      0     32
8     0  0  0  0  0  0  0  0  1  0  0  0  0  0  0  0  0      0      0     64 
9     0  0  0  0  0  0  0  0  0  1  0  0  0  0  0  0  0      0      1      0
10    0  0  0  0  0  0  0  0  0  0  1  0  0  0  0  0  0      0      2      0
11    0  0  0  0  0  0  0  0  0  0  0  1  0  0  0  0  0      0      4      0
12    0  0  0  0  0  0  0  0  0  0  0  0  1  0  0  0  0      0      8      0
13    0  0  0  0  0  0  0  0  0  0  0  0  0  1  0  0  0      0     16      0
14    0  0  0  0  0  0  0  0  0  0  0  0  0  0  1  0  0      0     32      0
15    0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  1  0      0     64      0
16    0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  1      0    128      0 

uint8_t PortAData[17] = {  0,  0,  2,  1,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0};
uint8_t PortBData[17] = {  0,  0,  0,  0,  0,  0,  0,  0,  0,  1,  2,  4,  8, 16, 32, 64,128};
uint8_t PortDData[17] = {  1,  2,  0,  0,  4,  8, 16, 32, 64,  0,  0,  0,  0,  0,  0,  0,  0};

 */
	  
 
#define shortdelay(); 			asm("nop\n\t" \ 
								"nop\n\t");
	 
#include <avr/io.h> 
 
int main (void)
{ 
uint8_t PA, PB, PD; 
uint8_t LEDno = 0;		
unsigned int  j;				//16-bit unsigned integer


uint8_t PortAData[17] = {  0,  0,  2,  1,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0};
uint8_t PortBData[17] = {  0,  0,  0,  0,  0,  0,  0,  0,  0,  1,  2,  4,  8, 16, 32, 64,128};
uint8_t PortDData[17] = {  1,  2,  0,  0,  4,  8, 16, 32, 64,  0,  0,  0,  0,  0,  0,  0,  0};


//Initialization routine: Clear watchdog timer-- this can prevent several things from going wrong.		
MCUSR  &= 0xF7;		//Clear WDRF Flag
WDTCSR	= 0x18;		//Set stupid bits so we can clear timer...
WDTCSR	= 0x00;
 
//Set all ports to output *EXCEPT* PA2 (reset pin)
//All IO lines will be used for output.
	DDRA = 3U;
	DDRB = 255U;	
	DDRD = 127U;
 	
	PORTA = 0;		
	PORTB = 0;	
	PORTD = 0;
    
for (;;)  // main loop
{

LEDno++;
	
if (LEDno > 16)	
	LEDno = 0;
  
 PA = PortAData[LEDno];
 PB = PortBData[LEDno];
 PD = PortDData[LEDno];
 
 j = 0;		
 while (j < 15000)		// This sets the delay time
 	{ 
 
  PORTA = PA;
  PORTB = PB;
  PORTD = PD;
  
  shortdelay();	
  shortdelay();
  
  PORTA = 0;
  PORTB = 0;
  PORTD = 0;	
 
  shortdelay();
    	
	j++;				
	} 
  
	}	//End main loop
	return 0;
}
